/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 * 
 * == BEGIN LICENSE ==
 * 
 * Licensed under the terms of any of the following licenses at your
 * choice:
 * 
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 * 
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 * 
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 * 
 * == END LICENSE ==
 */
package net.fckeditor;

import java.util.HashMap;
import java.util.Map;

public class ResourceType {

	private String name;
	private static Map<String, ResourceType> types = new HashMap<String, ResourceType>(
			4);
	public static final ResourceType FILE = new ResourceType("File");
	public static final ResourceType IMAGE = new ResourceType("Image");
	public static final ResourceType FLASH = new ResourceType("Flash");
	public static final ResourceType MEDIA = new ResourceType("Media");

	static {
		types.put(FILE.getName(), FILE);
		types.put(IMAGE.getName(), IMAGE);
		types.put(FLASH.getName(), FLASH);
		types.put(MEDIA.getName(), MEDIA);
	}

	public ResourceType(final String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	@Override
	public String toString() {

		return name;
	}

	public String getPath() {
		return "/" + name.toLowerCase();
	}

	public static ResourceType valueOf(final String name)
			throws NullPointerException, IllegalArgumentException {

		if (name == null)
			throw new NullPointerException();

		ResourceType rt = types.get(name);

		if (rt == null)
			throw new IllegalArgumentException();

		return rt;
	}

	public static boolean isValid(final String name) {
		return types.containsKey(name);
	}
	
	public static ResourceType getDefaultResourceType(final String name) {

		ResourceType rt = getResourceType(name);

		return rt == null ? FILE : rt;

	}

	public static ResourceType getResourceType(final String name) {

		try {
			return ResourceType.valueOf(name);
		} catch (IllegalArgumentException e) {
			return null;
		} catch (NullPointerException e) {
			return null;
		}
	}
	
	@Override
	public boolean equals(Object obj) {
		
		try {
			ResourceType rt = (ResourceType) obj;
			return name.equals(rt.getName());
		} catch (ClassCastException e) {
			return false;
		}
	}

}
